==> apache-pulsar-2.8.3-src.tar.gz: apache-pulsar-2.8.3-src/managed-ledger/src/main/java/org/apache/bookkeeper/mledger/impl/PositionImplRecyclable.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.bookkeeper.mledger.impl;

import org.apache.bookkeeper.mledger.Position;

import io.netty.util.Recycler;
import io.netty.util.Recycler.Handle;

public class PositionImplRecyclable extends PositionImpl implements Position {

    private final Handle<PositionImplRecyclable> recyclerHandle;

    private static final Recycler<PositionImplRecyclable> RECYCLER = new Recycler<PositionImplRecyclable>() {
        @Override
        protected PositionImplRecyclable newObject(Recycler.Handle<PositionImplRecyclable> recyclerHandle) {
            return new PositionImplRecyclable(recyclerHandle);
        }
    };

    private PositionImplRecyclable(Handle<PositionImplRecyclable> recyclerHandle) {
        super(PositionImpl.earliest);
        this.recyclerHandle = recyclerHandle;
    }

    public static PositionImplRecyclable create() {
        return RECYCLER.get();
    }

    public void recycle() {
        ackSet = null;
        recyclerHandle.recycle(this);
    }

}

==> apache-pulsar-2.10.0-src.tar.gz: apache-pulsar-2.10.0-src/managed-ledger/src/main/java/org/apache/bookkeeper/mledger/impl/PositionImplRecyclable.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.bookkeeper.mledger.impl;

import io.netty.util.Recycler;
import io.netty.util.Recycler.Handle;
import org.apache.bookkeeper.mledger.Position;

public class PositionImplRecyclable extends PositionImpl implements Position {

    private final Handle<PositionImplRecyclable> recyclerHandle;

    private static final Recycler<PositionImplRecyclable> RECYCLER = new Recycler<PositionImplRecyclable>() {
        @Override
        protected PositionImplRecyclable newObject(Recycler.Handle<PositionImplRecyclable> recyclerHandle) {
            return new PositionImplRecyclable(recyclerHandle);
        }
    };

    private PositionImplRecyclable(Handle<PositionImplRecyclable> recyclerHandle) {
        super(PositionImpl.EARLIEST);
        this.recyclerHandle = recyclerHandle;
    }

    public static PositionImplRecyclable create() {
        return RECYCLER.get();
    }

    public void recycle() {
        ackSet = null;
        recyclerHandle.recycle(this);
    }

}
